fn all_parent_mods_public(
hir_func: &Function,
ctx: &AssistContext<'_, '_>,
) -> boolExpand description
Checks that all parent modules of the function are public / exported
fn all_parent_mods_public(
hir_func: &Function,
ctx: &AssistContext<'_, '_>,
) -> boolChecks that all parent modules of the function are public / exported