fn build_path(
ast_func: &Fn,
ctx: &AssistContext<'_, '_>,
edition: Edition,
) -> Option<String>Expand description
Helper function to build the path of the module in the which is the node
fn build_path(
ast_func: &Fn,
ctx: &AssistContext<'_, '_>,
edition: Edition,
) -> Option<String>Helper function to build the path of the module in the which is the node