fn is_in_trait_impl(ast_func: &Fn, ctx: &AssistContext<'_, '_>) -> boolExpand description
Helper function to determine if the function is in a trait implementation
fn is_in_trait_impl(ast_func: &Fn, ctx: &AssistContext<'_, '_>) -> boolHelper function to determine if the function is in a trait implementation